package ru.mike.downloaderbot.processor.command;

import com.pengrad.telegrambot.TelegramBot;
import com.pengrad.telegrambot.model.Update;
import com.pengrad.telegrambot.request.SendMessage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import ru.mike.downloaderbot.domain.LinkData;
import ru.mike.downloaderbot.service.LinkDataService;

import java.util.List;

@Slf4j
@Component
public class LinkCommandProcessor implements CommandProcessor {
    @Autowired
    private TelegramBot telegramBot;

    @Autowired
    private LinkDataService linkDataService;

    @Override
    public boolean isSuitableCommand(String command) {
        return command.startsWith("/link");
    }

    @Override
    public void process(Update update) {
        List<Long> adminsIds = List.of(283573433L, 421233011L);

        Long currentUserId = update.message().from().id();
        Long currentChatId = update.message().chat().id();
        String text = update.message().text();

        if (!adminsIds.contains(currentUserId)) {
            log.warn("User:'{}' trying to send link:{}, but it's not admin", currentUserId, text);
            return;
        }

        String[] splitText = text.split(" ");

        if (splitText.length != 3) {
            SendMessage wrongFormatMessage = new SendMessage(currentChatId, "Неверный формат команды для генерации ссылки. " +
                    "Формат команды:/link <ссылка> <тег канала>");
            telegramBot.execute(wrongFormatMessage);
            return;
        }

        String linkText = splitText[1];
        String channelName = splitText[2];

        LinkData createdLinkData = linkDataService.createLinkData(linkText, channelName);

        SendMessage generatedLinkMessage = new SendMessage(currentChatId,
                "Сгенерированная ссылка:" + createdLinkData.getBotLink());

        telegramBot.execute(generatedLinkMessage);
    }
}
