package ru.mike.downloaderbot.processor.updatetype;

import com.pengrad.telegrambot.TelegramBot;
import com.pengrad.telegrambot.model.Update;
import com.pengrad.telegrambot.request.SendMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import ru.mike.downloaderbot.processor.command.CommandProcessor;

import java.util.List;
import java.util.Objects;
import java.util.Optional;

@Component
public class MessageUpdateTypeProcessor implements UpdateTypeProcessor {
    @Autowired
    private TelegramBot telegramBot;

    @Autowired
    private List<CommandProcessor> commandProcessors;

    @Override
    public boolean isSuitableProcessor(Update update) {
        return Objects.nonNull(update.message());
    }

    @Override
    public void process(Update update) {
        String text = update.message().text();
        Optional<CommandProcessor> commandProcessorOptional = commandProcessors.stream()
                .filter(cp -> cp.isSuitableCommand(text))
                .findFirst();

        if (commandProcessorOptional.isPresent()) {
            commandProcessorOptional.get().process(update);
        } else {
            SendMessage sendMessage = new SendMessage(
                    update.message().chat().id(),
                    "Я не понимаю тебя, попробуй другую команду!"
            );

            telegramBot.execute(sendMessage);
        }
    }
}
