package ru.mike.downloaderbot.service;

import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import ru.mike.downloaderbot.domain.Channel;
import ru.mike.downloaderbot.domain.Rule;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.UUID;

@Slf4j
@Service
public class RuleChannelService {
    public static final String TELEGRAM_CHANNEL_URL_PREFIX = "https://t.me/";
    @Autowired
    private RuleService ruleService;

    @Autowired
    private ChannelService channelService;

    @Transactional
    public Rule createRuleAndChannels(
            String ruleBaseChannelName,
            List<String> channelsNames,
            List<Long> channelsIds
    ) {
        Optional<Rule> ruleOptional = ruleService.findByChannelName(ruleBaseChannelName);
        Rule rule;

        if (ruleOptional.isEmpty()) {
            rule = Rule.builder()
                    .channelName(ruleBaseChannelName)
                    .build();
        } else {
            rule = ruleOptional.get();
        }

        Set<Channel> channels = createChannels(rule, channelsNames, channelsIds);
        channelService.deleteAllByRuleId(rule.getId());

        rule.setChannels(channels);

        return ruleService.save(rule);
    }

    public List<Channel> findChannelsByRuleChannelName(String name) {
        Optional<Rule> ruleOptional = ruleService.findByChannelName(name);

        if (ruleOptional.isEmpty()) {
            log.warn("Unable to find rule by name:{}", name);
            return new ArrayList<>();
        }

        UUID ruleId = ruleOptional.get().getId();
        List<Channel> channels = channelService.findAllByRuleId(ruleId);

        if (channels.isEmpty()) {
            log.info("Channels by rule id:'{}' not found", ruleId);
        }

        return channels;
    }

    private Set<Channel> createChannels(Rule rule, List<String> channelsNames, List<Long> channelsIds) {
        Set<Channel> channels = new HashSet<>();

        for (int i = 0; i < channelsNames.size(); i++) {
            String channelName = channelsNames.get(i);

            Channel channel = Channel.builder()
                    .name(channelName)
                    .link(TELEGRAM_CHANNEL_URL_PREFIX + channelName)
                    .rule(rule)
                    .telegramChannelId(channelsIds.get(i))
                    .build();

            channels.add(channel);
        }

        return channels;
    }
}
